@@ -101,7 +101,6 @@ class EventListener(QObject):
     configuration_settings_event = Signal(str, str, str)
     stop_thread_event = Signal()
     mda_settings_event = Signal(MMSettings)
-    settings_event = Signal(str, str, str)
     live_mode_event = Signal(bool)
     xy_stage_position_changed_event = Signal(tuple)
     stage_position_changed_event = Signal(float)
@@ -201,17 +200,13 @@ class EventListener(QObject):
                     if time.perf_counter() - self.last_custom_mda > 0.2:
                         settings = evt.get_settings()
                         settings = MMSettings(java_settings=settings)
+                        print(settings)
                         self.mda_settings_event.emit(settings)
                     self.last_custom_mda = time.perf_counter()
                 elif "DefaultLiveModeEvent" in eventString:
                     if not self.send_live_images:
                         self.blockImages = evt.get_is_on()
                     self.live_mode_event.emit(self.blockImages)
-                elif "CustomSettingsEvent" in eventString:
-                    self.settings_event.emit(
-                        evt.get_device(), evt.get_property(), evt.get_value()
-                    )
-                    print(evt.get_property(), evt.get_value())
                 elif "XYStagePositionChangedEvent" in eventString:
                     self.xy_stage_position_changed_event.emit(
                         (evt.get_x_pos(), evt.get_y_pos())
